<?php

namespace Unakit;

final class PostContext
{
    const  PREVIEW = 'preview' ;
    const  FULL = 'full' ;
}
final class MetaLocation
{
    const  NONE = 'none' ;
    const  BOTH = 'both' ;
    const  TOP = 'top' ;
    const  BOTTOM = 'bottom' ;
}
final class MetaType
{
    const  DATETIME = 'datetime' ;
    const  AUTHOR = 'author' ;
    const  CATEGORIES = 'categories' ;
    const  TAGS = 'tags' ;
    const  COMMENTS = 'comments' ;
}
class Meta
{
    public static  $types ;
    public static function get_types()
    {
        return self::$types;
    }
    
    public static  $locations ;
    public static function get_locations()
    {
        return self::$locations;
    }
    
    public static function get_location( $meta_type, $context = PostContext::FULL )
    {
        return ( isset( self::$locations[$meta_type] ) && isset( self::$locations[$meta_type][$context] ) ? self::$locations[$meta_type][$context] : false );
    }
    
    public static function update_locations( $locations )
    {
        self::$locations = $locations;
    }
    
    public static function is_visible( $meta_type, $location, $context = PostContext::FULL )
    {
        $visible_location = Customizer::get_mod( 'meta_location_' . $context . '_' . $meta_type );
        return $visible_location === $location || $visible_location === MetaLocation::BOTH;
    }
    
    public static  $titles ;
    public static function get_titles()
    {
        return self::$titles;
    }
    
    public static function get_title( $meta_type )
    {
        return ( isset( self::$titles[$meta_type] ) ? self::$titles[$meta_type] : '' );
    }
    
    public static function print_title( $meta_type )
    {
        echo  esc_html( self::get_title( $meta_type ) ) ;
    }
    
    public static  $icons ;
    public static function get_icons()
    {
        return self::$icons;
    }
    
    public static function get_icon( $meta_type )
    {
        return ( isset( self::$icons[$meta_type] ) ? self::$icons[$meta_type] : '' );
    }
    
    public static function print_icon( $meta_type )
    {
        echo  wp_kses_post( self::get_icon( $meta_type ) ) ;
    }
    
    public static  $early_initialized = false ;
    public static function early_init( $force = false )
    {
        if ( !$force && self::$early_initialized ) {
            return;
        }
        self::$types = [
            MetaType::DATETIME,
            MetaType::AUTHOR,
            MetaType::CATEGORIES,
            MetaType::TAGS,
            MetaType::COMMENTS
        ];
        self::$titles = [
            MetaType::DATETIME   => _x( 'Date/Time', 'Post Meta Label for date, time or date & time published', 'unakit' ),
            MetaType::AUTHOR     => _x( 'Author', 'Post Meta Label for author', 'unakit' ),
            MetaType::TAGS       => _x( 'Tags', 'Post Meta Label for tags', 'unakit' ),
            MetaType::CATEGORIES => _x( 'Categories', 'Post Meta Label for categories', 'unakit' ),
            MetaType::COMMENTS   => _x( 'Comments', 'Post Meta Label for comments number', 'unakit' ),
        ];
        self::$early_initialized = true;
    }
    
    public static function init()
    {
        Customizer::init();
        self::$locations = [
            MetaType::DATETIME   => [
            PostContext::PREVIEW => Customizer::get_mod( 'meta_location_preview_' . MetaType::DATETIME ),
            PostContext::FULL    => Customizer::get_mod( 'meta_location_full_' . MetaType::DATETIME ),
        ],
            MetaType::AUTHOR     => [
            PostContext::PREVIEW => Customizer::get_mod( 'meta_location_preview_' . MetaType::AUTHOR ),
            PostContext::FULL    => Customizer::get_mod( 'meta_location_full_' . MetaType::AUTHOR ),
        ],
            MetaType::TAGS       => [
            PostContext::PREVIEW => Customizer::get_mod( 'meta_location_preview_' . MetaType::TAGS ),
            PostContext::FULL    => Customizer::get_mod( 'meta_location_full_' . MetaType::TAGS ),
        ],
            MetaType::CATEGORIES => [
            PostContext::PREVIEW => Customizer::get_mod( 'meta_location_preview_' . MetaType::CATEGORIES ),
            PostContext::FULL    => Customizer::get_mod( 'meta_location_full_' . MetaType::CATEGORIES ),
        ],
            MetaType::COMMENTS   => [
            PostContext::PREVIEW => Customizer::get_mod( 'meta_location_preview_' . MetaType::COMMENTS ),
            PostContext::FULL    => Customizer::get_mod( 'meta_location_full_' . MetaType::COMMENTS ),
        ],
        ];
        self::$icons = [
            MetaType::DATETIME   => '<i class="fas fa-calendar-day meta_icon"></i>',
            MetaType::AUTHOR     => '<i class="fas fa-user meta_icon"></i>',
            MetaType::TAGS       => '<i class="fas fa-hashtag meta_icon"></i>',
            MetaType::CATEGORIES => '<i class="fas fa-tag meta_icon"></i>',
            MetaType::COMMENTS   => '<i class="fas fa-comments meta_icon"></i>',
        ];
    }

}