<?php

namespace Unakit;

$unakit_meta_location = (isset($args['location']) && ($args['location'] === MetaLocation::TOP || $args['location'] === MetaLocation::BOTTOM)) ? $args['location'] : MetaLocation::TOP;
$unakit_post_context = (isset($args['context']) && ($args['context'] === PostContext::PREVIEW || $args['context'] === PostContext::FULL)) ? $args['context'] : PostContext::PREVIEW;
$unakit_post_has_tags = boolval(get_the_tags());
$unakit_post_comments_number = get_comments_number();
$unakit_post_categories = get_the_terms($post->ID, 'category');
$unakit_post_categories_count = $unakit_post_categories ? count($unakit_post_categories) : 0;
$unakit_max_displayed_categories = 3;
$unakit_post_tags = get_the_terms($post->ID, 'post_tag');
$unakit_post_tags_count = $unakit_post_tags ? count($unakit_post_tags) : 0;
$unakit_max_displayed_tags = 3;

?>
<div class="meta meta--<?php echo esc_attr($unakit_meta_location); ?>">
    <?php
    if ($unakit_post_categories_count > 0 && Meta::is_visible(MetaType::CATEGORIES, $unakit_meta_location, $unakit_post_context)) : // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
    ?>
        <span class="meta__container meta__container--categories">
            <span class="meta__container__title screen-reader-text">
                <?php
                Meta::print_title(MetaType::CATEGORIES);
                ?>
            </span>
            <span class="meta__container__content">
                <span class="meta__list meta__list--categories">
                    <?php
                    $unakit_category_counter = 0;
                    for (; $unakit_category_counter < $unakit_post_categories_count && $unakit_category_counter < $unakit_max_displayed_categories; $unakit_category_counter++) {
                        $unakit_current_category = $unakit_post_categories[$unakit_category_counter];
                        echo '<a href="' . esc_url(get_term_link($unakit_current_category->slug, 'category')) . '" class="meta__list__item meta__list__item--categories category-' . esc_attr($unakit_current_category->slug) . '">' .
                            '<span class="meta__list__item__icon">' . wp_kses_post(Meta::get_icon(MetaType::CATEGORIES)) . '</span>' .
                            '<span class="meta__list__item__title">' . esc_html($unakit_current_category->name) . '</span>' .
                            '</a>';
                    }
                    $unakit_remaining_categories = $unakit_post_categories_count - $unakit_max_displayed_categories;
                    if ($unakit_remaining_categories > 0) {
                        $unakit_remaining_list = implode(', ', array_map(function ($x) {
                            return $x->name;
                        }, array_slice($unakit_post_categories, $unakit_category_counter)));
                        echo '<span class="meta__list__item meta__list__item--tags meta__list__item--remaining" title="' . esc_attr($unakit_remaining_list) . '">+&nbsp;' . esc_html($unakit_remaining_categories) . '</span>';
                    }
                    ?>
                </span>
            </span>
        </span>
    <?php endif;
    if (Meta::is_visible(MetaType::DATETIME, $unakit_meta_location, $unakit_post_context) && get_post_type() !== 'page') : ?>
        <span class="meta__container meta__container--datetime">
            <span class="meta__container__title screen-reader-text">
                <?php
                Meta::print_title(MetaType::DATETIME);
                ?>
            </span>
            <span class="meta__container__content">
                <a href="<?php echo the_permalink(); ?>">
                    <?php get_template_part('template-parts/datetime'); ?>
                </a>
            </span>
        </span>
    <?php endif;
    if (Meta::is_visible(MetaType::AUTHOR, $unakit_meta_location, $unakit_post_context)) : ?>
        <span class="meta__container meta__container--author">
            <span class="meta__container__title screen-reader-text">
                <?php
                Meta::print_title(MetaType::AUTHOR);
                ?>
            </span>

            <span class="meta__container__content">
                <?php the_author_posts_link(); ?>
            </span>
        </span>
    <?php endif;
    if ($unakit_post_has_tags && Meta::is_visible(MetaType::TAGS, $unakit_meta_location, $unakit_post_context)) : ?>
        <span class="meta__container meta__container--tags">
            <span class="meta__container__title screen-reader-text">
                <?php
                Meta::print_title(MetaType::TAGS);
                ?>
            </span>

            <span class="meta__container__content">
                <span class="meta__list meta__list--tags">
                    <?php

                    $unakit_tag_counter = 0;
                    for (; $unakit_tag_counter < $unakit_post_tags_count && $unakit_tag_counter < $unakit_max_displayed_tags; $unakit_tag_counter++) {
                        $unakit_current_tag = $unakit_post_tags[$unakit_tag_counter];
                        echo '<a href="' . esc_url(get_term_link($unakit_current_tag->slug, 'post_tag')) . '" class="meta__list__item meta__list__item--tags tag-' . esc_attr($unakit_current_tag->slug) . '">' .
                            '<span class="meta__list__item__icon">' . wp_kses_post(Meta::get_icon(MetaType::TAGS)) . '</span>' .
                            '<span class="meta__list__item__title">' . esc_html($unakit_current_tag->name) . '</span>' .
                            '</a>';
                    }
                    $unakit_remaining_tags = $unakit_post_tags_count - $unakit_max_displayed_tags;
                    if ($unakit_remaining_tags > 0) {
                        $unakit_remaining_list = implode(', ', array_map(function ($x) {
                            return $x->name;
                        }, array_slice($unakit_post_tags, $unakit_tag_counter)));
                        echo '<span class="meta__list__item meta__list__item--tags meta__list__item--remaining" title="' . esc_attr($unakit_remaining_list) . '">+&nbsp;' . esc_html($unakit_remaining_tags) . '</span>';
                    }
                    ?>
                </span>
            </span>
        </span>
    <?php endif;
    if ($unakit_post_comments_number > 0 && Meta::is_visible(MetaType::COMMENTS, $unakit_meta_location, $unakit_post_context)) : ?>
        <span class="meta__container meta__container--comments">
            <span class="meta__container__title screen-reader-text">
                <?php
                Meta::print_title(MetaType::COMMENTS);
                ?>
            </span>
            <span class="meta__container__content">
                <a href="<?php echo the_permalink() . '/#comments'; ?>">
                    <?php
                    printf(
                        // translators: %s: number of comments
                        esc_html(_n(
                            '%s comment',
                            '%s comments',
                            $unakit_post_comments_number,
                            'unakit'
                        )),
                        esc_html(number_format_i18n($unakit_post_comments_number))
                    );
                    ?>
                </a>
            </span>
        </span>
    <?php endif; ?>
</div>